==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/dump/lang/dump_vi.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/dump?lang_cible=vi
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_restaurer_base' => 'Phục hồi database',

	// I
	'info_restauration_sauvegarde' => 'Phục hồi hồ sơ dự trữ @archive@', # MODIF
	'info_sauvegarde' => 'Dự trữ',
	'info_sauvegarde_reussi_02' => 'Database được lưu trữ trong @archive@. Bạn có thể ', # MODIF
	'info_sauvegarde_reussi_03' => 'trở lại việc quản trị',
	'info_sauvegarde_reussi_04' => 'website của bạn.',

	// T
	'texte_admin_tech_01' => 'Chọn lựa này cho phép bạn giữ lại nội dung của database vào trong một hồ sơ đựng trong ngăn @dossier@. Và cũng đừng quên cất giữ lại lại toàn bộ ngăn <i>IMG/</i>, chứa đựng các hình ảnh dùng trong các bài vở và đề mục.', # MODIF
	'texte_admin_tech_02' => '<b>Cảnh báo</b>: CHỈ CÓ THỂ phục hồi bản dự trữ này trong một website có cùng ấn bản SPIP.
 Lỗi lầm thường hay vấp phải là thực hiện việc dự trữ database trước khi nâng cấp SPIP...
 Để biết thêm, xin đọc [tài liệu SPIP->http://www.spip.net/fr_article1489.html].', # MODIF
	'texte_restaurer_base' => 'Phục hồi nội dung của kho dự trữ database',
	'texte_restaurer_sauvegarde' => 'Chọn lựa này cho phép bạn phục hồi một hồ sơ dự trữ trước đó của database. Để thực hiện điều này, hồ sơ chứa phần dự trữ phải được nên giữ ở thư mục @dossier@. Cẩn thận với đặc điểm này: <b>Bất cứ sửa đổi hay thất thoát nào xảy ra là không làm ngược lại được.</b>', # MODIF
	'texte_sauvegarde' => 'Dự trữ nội dung của database',
	'texte_sauvegarde_base' => 'Dự trữ database'
);

==> spip_4.4.7+dfsg.orig.tar.xz: plugins-dist/dump/lang/dump_vi.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/dump?lang_cible=vi
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_restaurer_base' => 'Phục hồi database',

	// I
	'info_restauration_sauvegarde' => 'Phục hồi hồ sơ dự trữ @archive@', # MODIF
	'info_sauvegarde' => 'Dự trữ',
	'info_sauvegarde_reussi_02' => 'Database được lưu trữ trong @archive@. Bạn có thể ', # MODIF
	'info_sauvegarde_reussi_03' => 'trở lại việc quản trị',
	'info_sauvegarde_reussi_04' => 'website của bạn.',

	// T
	'texte_admin_tech_01' => 'Chọn lựa này cho phép bạn giữ lại nội dung của database vào trong một hồ sơ đựng trong ngăn @dossier@. Và cũng đừng quên cất giữ lại lại toàn bộ ngăn <i>IMG/</i>, chứa đựng các hình ảnh dùng trong các bài vở và đề mục.', # MODIF
	'texte_admin_tech_02' => '<b>Cảnh báo</b>: CHỈ CÓ THỂ phục hồi bản dự trữ này trong một website có cùng ấn bản SPIP.
 Lỗi lầm thường hay vấp phải là thực hiện việc dự trữ database trước khi nâng cấp SPIP...
 Để biết thêm, xin đọc [tài liệu SPIP->http://www.spip.net/fr_article1489.html].', # MODIF
	'texte_restaurer_base' => 'Phục hồi nội dung của kho dự trữ database',
	'texte_restaurer_sauvegarde' => 'Chọn lựa này cho phép bạn phục hồi một hồ sơ dự trữ trước đó của database. Để thực hiện điều này, hồ sơ chứa phần dự trữ phải được nên giữ ở thư mục @dossier@. Cẩn thận với đặc điểm này: <b>Bất cứ sửa đổi hay thất thoát nào xảy ra là không làm ngược lại được.</b>', # MODIF
	'texte_sauvegarde' => 'Dự trữ nội dung của database',
	'texte_sauvegarde_base' => 'Dự trữ database',
];
